/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.internal.common.MessageDialog");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("dojox.data.dom");
dojo.require("net.jazz.ajax.ui.internal.Dialog");
dojo.require("com.ibm.rational.report.web.core.app.internal.common.CommonDialog");
dojo.requireLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");

var CommonMessages	= dojo.i18n.getLocalization("com.ibm.rational.report.web.core.app.internal.common", "Messages");
var errorIcon		= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/images/error.gif");
var warningIcon		= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/images/warning.gif");
var informationIcon	= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/images/info.gif");
var successIcon		= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/images/success.gif");

/**
 * Displays a confirmation dialog. Takes the following parameters:
 *     title: the dialog title
 *     prompt: the prompt to be displayed
 *     promptType: the prompt type ("Error", "Warning", "Information")
 *     buttonType: the button type ("Ok", "OkCancel", "YesNo")
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.internal.common.MessageDialog",
	[dijit._Widget, dijit._Templated], {
		
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/templates/MessageDialog.html"),
	
	widgetsInTemplate: true,
	
	constructor: function (args) {
		this._args = args;
	},
	
	postCreate: function () {
		var promptType = this._args.promptType;
		if (promptType != null && typeof promptType != "undefined" && promptType != "") {
			var img = document.createElement("img");
			if (promptType == "Error") {
				img.src = errorIcon;
			}
			else if (promptType == "Warning") {
				img.src = warningIcon;
			}
			else if (promptType == "Information") {
				img.src = informationIcon;
			}
			else {
				img.src = successIcon;
			}
			img.className = "messageIcon";
			this.prompt.appendChild(img);
		}
		
		var prompt = this._args.prompt;
		if (prompt != null && typeof prompt != "undefined" && prompt != "") {
			this.prompt.appendChild(document.createTextNode(prompt));
		}
		
		var buttonType = this._args.buttonType;
		if (buttonType != null && typeof buttonType != "undefined" && buttonType != "") {
			if (buttonType == "Ok") {
				this.leftButton.style.display = "none";
				dojox.data.dom.removeChildren(this.rightButton);
				this.rightButton.appendChild(document.createTextNode(CommonMessages.OK_BUTTON_LABEL));				
			}			
			if (buttonType == "OkCancel") {
				dojox.data.dom.removeChildren(this.leftButton);
				this.leftButton.appendChild(document.createTextNode(CommonMessages.OK_BUTTON_LABEL));
				dojox.data.dom.removeChildren(this.rightButton);
				this.rightButton.appendChild(document.createTextNode(CommonMessages.CANCEL_BUTTON_LABEL));				
			}			
			else if (buttonType == "YesNo") {
				dojox.data.dom.removeChildren(this.leftButton);
				this.leftButton.appendChild(document.createTextNode(CommonMessages.YES_BUTTON_LABEL));
				dojox.data.dom.removeChildren(this.rightButton);
				this.rightButton.appendChild(document.createTextNode(CommonMessages.NO_BUTTON_LABEL));				
			}
		}
				
		var self = this;
		this.dialog = new com.ibm.rational.report.web.core.app.internal.common.CommonDialog({
			contentNode: this.contentNode,
			primaryTitle: this._args.title,
			width: "400px",
			isClosable: this._args.isClosable
		});
		
		this.rightButton.focus();	
	},
	
	disableCloseButton: function() {
		this.dialog.disableCloseButton();
	},	
	
	showErrorMessage: function (msg) {
		this.messageArea.className = "error";
		dojox.data.dom.removeChildren(this.messageArea);
		this.messageArea.appendChild(document.createTextNode(msg));
	},
	
	close: function() {
		this.dialog.close();
	}
	
});

})();